==> ktp-desktop-applets-22.04.2.tar.xz: ktp-desktop-applets-22.04.2/chat/org.kde.ktp-chat/metadata.desktop.cmake <==
[Desktop Entry]
Name=Quick Chat
Name[ar]=محادثة سريعة
Name[bs]=Brzo ćaskanje
Name[ca]=Xat ràpid
Name[ca@valencia]=Chat ràpid
Name[cs]=Rychlý rozhovor
Name[da]=Kvikchat
Name[de]=Schnell-Chat
Name[el]=Σύντομη συνομιλία
Name[en_GB]=Quick Chat
Name[es]=Charla rápida
Name[et]=Kiirvestlus
Name[eu]=Berriketa azkarra
Name[fi]=Pikakeskustelu
Name[fr]=Conversation rapide
Name[gl]=Conversa rápida
Name[hi]=त्वरित वार्तालाप
Name[hu]=Gyors csevegés
Name[ia]=Conversation rapide
Name[it]=Chat veloce
Name[kk]=Жедел чат-әңгіме
Name[ko]=빠른 대화
Name[lt]=Greitas pokalbis
Name[mr]=त्वरित गप्पा
Name[nb]=Kjapp prat
Name[nds]=Fixklönen
Name[nl]=Snelle chat
Name[nn]=Snøggprat
Name[pa]=ਤੁਰੰਤ ਗੱਲਬਾਤ
Name[pl]=Szybkie rozmowy
Name[pt]=Conversa Rápida
Name[pt_BR]=Conversa rápida
Name[ro]=Discuție rapidă
Name[ru]=Быстрый чат
Name[sk]=Rýchly rozhovor
Name[sl]=Hitri klepet
Name[sr]=Брзо ћаскање
Name[sr@ijekavian]=Брзо ћаскање
Name[sr@ijekavianlatin]=Brzo ćaskanje
Name[sr@latin]=Brzo ćaskanje
Name[sv]=Snabbchatt
Name[tr]=Hızlı Sohbet
Name[ug]=تېز پاراڭ
Name[uk]=Швидке спілкування
Name[x-test]=xxQuick Chatxx
Name[zh_CN]=快捷聊天
Name[zh_TW]=快速聊天
Comment=Simple chats from your workspace
Comment[ar]=محادثات بسيطة من مساحة العمل
Comment[bs]=Prosta ćaskanja iz radnog prostora
Comment[ca]=Xats normals des de l'espai de treball
Comment[ca@valencia]=Chats normals des de l'espai de treball
Comment[cs]=Jednoduché rozhovory z vaší pracovní plochy
Comment[da]=Simple chats fra dit arbejdsområde
Comment[de]=Einfache Chats von Ihrem Arbeitsbereich
Comment[el]=Απλές συνομιλίες από τον χώρο εργασίας σας
Comment[en_GB]=Simple chats from your workspace
Comment[es]=Charlas rápidas desde el espacio de trabajo
Comment[et]=Lihtne vestlus otse töölaualt
Comment[eu]=Berriketa xumeak zure mahaigainetik
Comment[fi]=Yksinkertaiset keskustelut työtilastasi
Comment[fr]=Conversations instantanées faciles à partir de votre espace de travail
Comment[gl]=Conversas simples desde o espazo de traballo.
Comment[hi]=आपके कार्यक्षेत्र से साधारण वार्तालाप
Comment[hu]=Egyszerű csevegések a munkaterületről
Comment[ia]=Simplice conversationes in directo ab tu spatio de labor
Comment[it]=Chat semplici per l'ambiente di lavoro
Comment[kk]=Жұмыс орыннан қарапайым чаты
Comment[ko]=작업 공간에서 빠르게 대화하기
Comment[lt]=Paprastas pokalbis iš Jūsų darbalaukio
Comment[mr]=तुमच्या कार्यस्थानातून सोप्या गप्पा
Comment[nb]=Enkel prat fra arbeidsflaten
Comment[nds]=Eenfach Klönen ut Dien Arbeitrebeet
Comment[nl]=Eenvoudige chats vanuit uw werkruimte
Comment[nn]=Enkel prat frå arbeidsflata
Comment[pa]=ਤੁਹਾਡੇ ਵਰਕਸਪੇਸ ਤੋਂ ਆਮ ਗੱਲਾਬਾਤਾਂ
Comment[pl]=Rozmowy z twojej przestrzeni pracy
Comment[pt]=Conversas simples a partir da sua área de trabalho
Comment[pt_BR]=Conversas simples a partir do seu ambiente de trabalho
Comment[ro]=Discuții simple de pe spațiul de lucru
Comment[ru]=Простой виджет для общения
Comment[sk]=Jednoduché rozhovory z vašej plochy
Comment[sl]=Preprosti klepeti iz vašega delovnega prostora
Comment[sr]=Брза ћаскања са радног простора
Comment[sr@ijekavian]=Брза ћаскања са радног простора
Comment[sr@ijekavianlatin]=Brza ćaskanja sa radnog prostora
Comment[sr@latin]=Brza ćaskanja sa radnog prostora
Comment[sv]=Enkel chatt från arbetsytan
Comment[tr]=Çalışma alanınızdan basit sohbetler
Comment[uk]=Прості вікна спілкування з вашого робочого простору
Comment[x-test]=xxSimple chats from your workspacexx
Comment[zh_CN]=从您的工作区上进行简单的聊天
Comment[zh_TW]=從您的工作空間發起聊天
Icon=telepathy-kde

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-RequiredExtensions=LaunchApp

X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
# X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Name=org.kde.ktp-chat
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@

X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet

#not entirely sure why this is there, I just know everything implodes without it
Type=Service

==> ktp-desktop-applets_22.08.1.orig.tar.xz: ktp-desktop-applets-22.08.1/chat/org.kde.ktp-chat/metadata.desktop.cmake <==
[Desktop Entry]
Name=Quick Chat
Name[ar]=محادثة سريعة
Name[bs]=Brzo ćaskanje
Name[ca]=Xat ràpid
Name[ca@valencia]=Xat ràpid
Name[cs]=Rychlý rozhovor
Name[da]=Kvikchat
Name[de]=Schnell-Chat
Name[el]=Σύντομη συνομιλία
Name[en_GB]=Quick Chat
Name[es]=Charla rápida
Name[et]=Kiirvestlus
Name[eu]=Berriketa azkarra
Name[fi]=Pikakeskustelu
Name[fr]=Conversation rapide
Name[gl]=Conversa rápida
Name[hi]=त्वरित वार्तालाप
Name[hu]=Gyors csevegés
Name[ia]=Conversation rapide
Name[it]=Chat veloce
Name[kk]=Жедел чат-әңгіме
Name[ko]=빠른 대화
Name[lt]=Greitas pokalbis
Name[mr]=त्वरित गप्पा
Name[nb]=Kjapp prat
Name[nds]=Fixklönen
Name[nl]=Snelle chat
Name[nn]=Snøggprat
Name[pa]=ਤੁਰੰਤ ਗੱਲਬਾਤ
Name[pl]=Szybkie rozmowy
Name[pt]=Conversa Rápida
Name[pt_BR]=Conversa rápida
Name[ro]=Discuție rapidă
Name[ru]=Быстрый чат
Name[sk]=Rýchly rozhovor
Name[sl]=Hitri klepet
Name[sr]=Брзо ћаскање
Name[sr@ijekavian]=Брзо ћаскање
Name[sr@ijekavianlatin]=Brzo ćaskanje
Name[sr@latin]=Brzo ćaskanje
Name[sv]=Snabbchatt
Name[tr]=Hızlı Sohbet
Name[ug]=تېز پاراڭ
Name[uk]=Швидке спілкування
Name[x-test]=xxQuick Chatxx
Name[zh_CN]=快捷聊天
Name[zh_TW]=快速聊天
Comment=Simple chats from your workspace
Comment[ar]=محادثات بسيطة من مساحة العمل
Comment[bs]=Prosta ćaskanja iz radnog prostora
Comment[ca]=Xats normals des de l'espai de treball
Comment[ca@valencia]=Xats normals des de l'espai de treball
Comment[cs]=Jednoduché rozhovory z vaší pracovní plochy
Comment[da]=Simple chats fra dit arbejdsområde
Comment[de]=Einfache Chats von Ihrem Arbeitsbereich
Comment[el]=Απλές συνομιλίες από τον χώρο εργασίας σας
Comment[en_GB]=Simple chats from your workspace
Comment[es]=Charlas rápidas desde el espacio de trabajo
Comment[et]=Lihtne vestlus otse töölaualt
Comment[eu]=Berriketa xumeak zure mahaigainetik
Comment[fi]=Yksinkertaiset keskustelut työtilastasi
Comment[fr]=Conversations instantanées faciles à partir de votre espace de travail
Comment[gl]=Conversas simples desde o espazo de traballo.
Comment[hi]=आपके कार्यक्षेत्र से साधारण वार्तालाप
Comment[hu]=Egyszerű csevegések a munkaterületről
Comment[ia]=Simplice conversationes in directo ab tu spatio de labor
Comment[it]=Chat semplici per l'ambiente di lavoro
Comment[kk]=Жұмыс орыннан қарапайым чаты
Comment[ko]=작업 공간에서 빠르게 대화하기
Comment[lt]=Paprastas pokalbis iš Jūsų darbalaukio
Comment[mr]=तुमच्या कार्यस्थानातून सोप्या गप्पा
Comment[nb]=Enkel prat fra arbeidsflaten
Comment[nds]=Eenfach Klönen ut Dien Arbeitrebeet
Comment[nl]=Eenvoudige chats vanuit uw werkruimte
Comment[nn]=Enkel prat frå arbeidsflata
Comment[pa]=ਤੁਹਾਡੇ ਵਰਕਸਪੇਸ ਤੋਂ ਆਮ ਗੱਲਾਬਾਤਾਂ
Comment[pl]=Rozmowy z twojej przestrzeni pracy
Comment[pt]=Conversas simples a partir da sua área de trabalho
Comment[pt_BR]=Conversas simples a partir do seu ambiente de trabalho
Comment[ro]=Discuții simple de pe spațiul de lucru
Comment[ru]=Простой виджет для общения
Comment[sk]=Jednoduché rozhovory z vašej plochy
Comment[sl]=Preprosti klepeti iz vašega delovnega prostora
Comment[sr]=Брза ћаскања са радног простора
Comment[sr@ijekavian]=Брза ћаскања са радног простора
Comment[sr@ijekavianlatin]=Brza ćaskanja sa radnog prostora
Comment[sr@latin]=Brza ćaskanja sa radnog prostora
Comment[sv]=Enkel chatt från arbetsytan
Comment[tr]=Çalışma alanınızdan basit sohbetler
Comment[uk]=Прості вікна спілкування з вашого робочого простору
Comment[x-test]=xxSimple chats from your workspacexx
Comment[zh_CN]=嵌入在工作区中的简易聊天小程序
Comment[zh_TW]=從您的工作空間發起聊天
Icon=telepathy-kde

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-RequiredExtensions=LaunchApp

X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
# X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Name=org.kde.ktp-chat
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@

X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet

#not entirely sure why this is there, I just know everything implodes without it
Type=Service
